==> qtjambi-multimedia-debuginfo-macos-6.5.4.jar: sources/QtJambiMultimedia/QAudioSource_shell.h <==
#ifndef QAUDIOSOURCE_SHELL_H
#define QAUDIOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudio.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtMultimedia/qaudioformat.h>
#include <QtJambi/RegistryAPI>


class QAudioSource_shell : public QAudioSource, public QtJambiShellInterface
{
public:
    QAudioSource_shell(const QAudioDevice& audioDeviceInfo0, const QAudioFormat& format1 = QAudioFormat(), QObject* parent2 = nullptr);
    QAudioSource_shell(const QAudioFormat& format0 = QAudioFormat(), QObject* parent1 = nullptr);
    ~QAudioSource_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioSource_access : public QAudioSource
{
};

#endif // QAUDIOSOURCE_SHELL_H

==> qtjambi-multimedia-debuginfo-macos-6.7.1.jar: sources/QtJambiMultimedia/QAudioSource_shell.h <==
#ifndef QAUDIOSOURCE_SHELL_H
#define QAUDIOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtMultimedia/qaudio.h>
#include <QtMultimedia/qaudiodevice.h>
#include <QtMultimedia/qaudioformat.h>
#include <QtJambi/RegistryAPI>


class QAudioSource_shell : public QAudioSource, public QtJambiShellInterface
{
public:
    QAudioSource_shell(const QAudioDevice& audioDeviceInfo0, const QAudioFormat& format1 = QAudioFormat(), QObject* parent2 = nullptr);
    QAudioSource_shell(const QAudioFormat& format0 = QAudioFormat(), QObject* parent1 = nullptr);
    ~QAudioSource_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QAudioSource_mshell;
    friend class QAudioSource_oshell;
};


class QAudioSource_mshell : public QAudioSource_shell
{
public:
    using QAudioSource_shell::QAudioSource_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAudioSource_oshell : public QAudioSource_mshell
{
public:
    using QAudioSource_mshell::QAudioSource_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioSource_access : public QAudioSource
{
};

#endif // QAUDIOSOURCE_SHELL_H
